==> nextcloud-21.0.5.tgz: nextcloud/apps/dav/l10n/tr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Takvim",
    "Todos" : "Yapılacak işler",
    "Personal" : "Kişisel",
    "{actor} created calendar {calendar}" : "{actor}, {calendar} takvimini ekledi",
    "You created calendar {calendar}" : "{calendar} takvimini eklediniz",
    "{actor} deleted calendar {calendar}" : "{actor}, {calendar} takvimini sildi",
    "You deleted calendar {calendar}" : "{calendar} takvimini sildiniz",
    "{actor} updated calendar {calendar}" : "{actor}, {calendar} takvimini güncelledi",
    "You updated calendar {calendar}" : "{calendar} takvimini güncellediniz",
    "{actor} restored calendar {calendar}" : "{actor}, {calendar} takvimini geri yükledi",
    "You restored calendar {calendar}" : "{calendar} takvimini geri yüklediniz",
    "You shared calendar {calendar} as public link" : "{calendar} takvimini herkese açık bağlantı olarak paylaştınız",
    "You removed public link for calendar {calendar}" : "{calendar} takviminin herkese açık bağlantısını kaldırdınız",
    "{actor} shared calendar {calendar} with you" : "{actor}, {calendar} takvimini sizinle paylaştı",
    "You shared calendar {calendar} with {user}" : "{calendar} takvimini {user} kullanıcısı ile paylaştınız",
    "{actor} shared calendar {calendar} with {user}" : "{actor}, {calendar} takvimini {user} kullanıcısı ile paylaştı",
    "{actor} unshared calendar {calendar} from you" : "{actor}, {calendar} takviminin sizinle paylaşımını kaldırdı",
    "You unshared calendar {calendar} from {user}" : "{calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from {user}" : "{actor}, {calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}, {calendar} takviminin kendisi ile paylaşımını kaldırdı",
    "You shared calendar {calendar} with group {group}" : "{calendar} takvimini {group} grubu ile paylaştınız",
    "{actor} shared calendar {calendar} with group {group}" : "{actor}, {calendar} takvimini {group} grubu ile paylaştı",
    "You unshared calendar {calendar} from group {group}" : "{calendar} takviminin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}, {calendar} takviminin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created event {event} in calendar {calendar}" : "{actor}, {calendar} takvimine {event} etkinliğini ekledi",
    "You created event {event} in calendar {calendar}" : "{calendar} takvimine {event} etkinliğini eklediniz",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}, {calendar} takviminden {event} etkinliğini sildi",
    "You deleted event {event} from calendar {calendar}" : "{calendar} takviminden {event} etkinliğini sildiniz",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini güncelledi",
    "You updated event {event} in calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini güncellediniz",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini geri yükledi",
    "You restored event {event} of calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini geri yüklediniz",
    "Busy" : "Meşgul",
    "{actor} created todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesine {todo} yapılacak işini ekledi",
    "You created todo {todo} in list {calendar}" : "{calendar} takvimi listesine {todo} yapılacak işini eklediniz",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor}, {calendar} takvimi listesinden {todo} yapılacak işini sildi",
    "You deleted todo {todo} from list {calendar}" : "{calendar} takvimi listesinden {todo} yapılacak işini sildiniz",
    "{actor} updated todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini güncelledi",
    "You updated todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini güncellediniz",
    "{actor} solved todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini tamamladı",
    "You solved todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini tamamladınız",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattı",
    "You reopened todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattınız",
    "Calendar, contacts and tasks" : "Takvim, kişiler ve görevler",
    "A <strong>calendar</strong> was modified" : "Bir <strong>takvim</strong> düzenlendi",
    "A calendar <strong>event</strong> was modified" : "Bir takvim <strong>etkinliği</strong> düzenlendi",
    "A calendar <strong>todo</strong> was modified" : "Bir takvim <strong>yapılacak işi</strong> düzenlendi",
    "Contact birthdays" : "Kişi doğum günleri",
    "Death of %s" : "%s ölümü",
    "Calendar:" : "Takvim:",
    "Date:" : "Tarih:",
    "Where:" : "Yer:",
    "Description:" : "Açıklama:",
    "Untitled event" : "Başlıksız etkinlik",
    "_%n year_::_%n years_" : ["%n yıl","%n yıl"],
    "_%n month_::_%n months_" : ["%n ay","%n ay"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "_%n hour_::_%n hours_" : ["%n saat","%n saat"],
    "_%n minute_::_%n minutes_" : ["%n dakika","%n dakika"],
    "%s (in %s)" : "%s (%s içinde)",
    "%s (%s ago)" : "%s (%s önce)",
    "Calendar: %s" : "Takvim: %s",
    "Date: %s" : "Tarih: %s",
    "Description: %s" : "Açıklama: %s",
    "Where: %s" : "Şurada: %s",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "Cancelled: %1$s" : "İptal edildi: %1$s",
    "Invitation canceled" : "Çağrı iptal edildi",
    "Re: %1$s" : "Ynt: %1$s",
    "Invitation updated" : "Çağrı güncellendi",
    "Invitation: %1$s" : "Çağrı: %1$s",
    "Invitation" : "Çağrı",
    "Title:" : "Başlık:",
    "Time:" : "Zaman:",
    "Location:" : "Konum:",
    "Link:" : "Bağlantı:",
    "Organizer:" : "Düzenleyen:",
    "Attendees:" : "Katılımcılar:",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "More options …" : "Diğer seçenekler …",
    "More options at %s" : "%s üzerindeki diğer seçenekler",
    "Contacts" : "Kişiler",
    "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
    "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
    "{actor} deleted address book {addressbook}" : "{actor}, {addressbook} adres defterini sildi",
    "You deleted address book {addressbook}" : "{addressbook} adres defterini sildiniz",
    "{actor} updated address book {addressbook}" : "{actor}, {addressbook} adres defterini güncelledi",
    "You updated address book {addressbook}" : "{addressbook} adres defterini güncellediniz",
    "{actor} shared address book {addressbook} with you" : "{actor}, {addressbook} adres defterini sizinle paylaştı",
    "You shared address book {addressbook} with {user}" : "{addressbook} adres defterini {user} kullanıcısı ile paylaştınız",
    "{actor} shared address book {addressbook} with {user}" : "{actor}, {addressbook} adres defterini {user} kullanıcısı ile paylaştı",
    "{actor} unshared address book {addressbook} from you" : "{actor}, {addressbook} adres defterinin sizinle paylaşımını kaldırdı",
    "You unshared address book {addressbook} from {user}" : "{addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}, {addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}, {addressbook} adres defterinin kendileri ile paylaşımını kaldırdı",
    "You shared address book {addressbook} with group {group}" : "{addressbook} adres defterini {group} grubu ile paylaştınız",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}, {addressbook} adres defterini {group} grubu ile paylaştı",
    "You unshared address book {addressbook} from group {group}" : "{addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}, {addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterine {card} kişi kartını ekledi",
    "You created contact {card} in address book {addressbook}" : "{addressbook} adres defterine {card} kişi kartını eklediniz",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}, {addressbook} adres defterinden {card} kişi kartını sildi",
    "You deleted contact {card} from address book {addressbook}" : "{addressbook} adres defterinden {card} kişi kartını sildiniz",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterindeki {card} kişi kartını güncelledi",
    "You updated contact {card} in address book {addressbook}" : "{addressbook} adres defterindeki {card} kişi kartını güncellediniz",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Bir <strong>kişi</strong> ya da <strong>adres defteri</strong> değiştirildi",
    "System is in maintenance mode." : "Sistem bakım kipinde.",
    "Upgrade needed" : "Yükseltme gerekiyor",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
    "Configures a CalDAV account" : "Bir CalDAV hesabı yapılandırır",
    "Configures a CardDAV account" : "Bir CardDAV hesabı yapılandırır",
    "Events" : "Etkinlikler",
    "Tasks" : "Görevler",
    "Untitled task" : "Başlıksız görev",
    "Completed on %s" : "%s tarihinde tamamlandı",
    "Due on %s by %s" : "%s tarihine kadar %s tarafından",
    "Due on %s" : "%s tarihine kadar",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV bağlantı noktası",
    "Calendar server" : "Takvim sunucusu",
    "Send invitations to attendees" : "Katılımcılara çağrıları gönder",
    "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
    "Birthday calendars will be generated by a background job." : "Bu seçenek etkinleştirildiğinde, doğum günü takvimi arka plan görevi olarak oluşturulur.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Etkinleştirildikten hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
    "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
    "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
    "Enable notifications for events via push" : "Anında etkinlik bildirimleri kullanılsın",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
    "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
    "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
    "Are you accepting the invitation?" : "Çağrıyı kabul ediyor musunuz?",
    "Tentative" : "Kesin değil",
    "Save" : "Kaydet",
    "Your attendance was updated successfully." : "Katılımınız güncellendi.",
    "Calendar and tasks" : "Takvim ve görevler"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-21.0.8.tgz: nextcloud/apps/dav/l10n/tr.js <==
OC.L10N.register(
    "dav",
    {
    "Calendar" : "Takvim",
    "Todos" : "Yapılacak işler",
    "Personal" : "Kişisel",
    "{actor} created calendar {calendar}" : "{actor}, {calendar} takvimini ekledi",
    "You created calendar {calendar}" : "{calendar} takvimini eklediniz",
    "{actor} deleted calendar {calendar}" : "{actor}, {calendar} takvimini sildi",
    "You deleted calendar {calendar}" : "{calendar} takvimini sildiniz",
    "{actor} updated calendar {calendar}" : "{actor}, {calendar} takvimini güncelledi",
    "You updated calendar {calendar}" : "{calendar} takvimini güncellediniz",
    "{actor} restored calendar {calendar}" : "{actor}, {calendar} takvimini geri yükledi",
    "You restored calendar {calendar}" : "{calendar} takvimini geri yüklediniz",
    "You shared calendar {calendar} as public link" : "{calendar} takvimini herkese açık bağlantı olarak paylaştınız",
    "You removed public link for calendar {calendar}" : "{calendar} takviminin herkese açık bağlantısını kaldırdınız",
    "{actor} shared calendar {calendar} with you" : "{actor}, {calendar} takvimini sizinle paylaştı",
    "You shared calendar {calendar} with {user}" : "{calendar} takvimini {user} kullanıcısı ile paylaştınız",
    "{actor} shared calendar {calendar} with {user}" : "{actor}, {calendar} takvimini {user} kullanıcısı ile paylaştı",
    "{actor} unshared calendar {calendar} from you" : "{actor}, {calendar} takviminin sizinle paylaşımını kaldırdı",
    "You unshared calendar {calendar} from {user}" : "{calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from {user}" : "{actor}, {calendar} takviminin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared calendar {calendar} from themselves" : "{actor}, {calendar} takviminin kendisi ile paylaşımını kaldırdı",
    "You shared calendar {calendar} with group {group}" : "{calendar} takvimini {group} grubu ile paylaştınız",
    "{actor} shared calendar {calendar} with group {group}" : "{actor}, {calendar} takvimini {group} grubu ile paylaştı",
    "You unshared calendar {calendar} from group {group}" : "{calendar} takviminin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor}, {calendar} takviminin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created event {event} in calendar {calendar}" : "{actor}, {calendar} takvimine {event} etkinliğini ekledi",
    "You created event {event} in calendar {calendar}" : "{calendar} takvimine {event} etkinliğini eklediniz",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor}, {calendar} takviminden {event} etkinliğini sildi",
    "You deleted event {event} from calendar {calendar}" : "{calendar} takviminden {event} etkinliğini sildiniz",
    "{actor} updated event {event} in calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini güncelledi",
    "You updated event {event} in calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini güncellediniz",
    "{actor} restored event {event} of calendar {calendar}" : "{actor}, {calendar} takvimindeki {event} etkinliğini geri yükledi",
    "You restored event {event} of calendar {calendar}" : "{calendar} takvimindeki {event} etkinliğini geri yüklediniz",
    "Busy" : "Meşgul",
    "{actor} created todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesine {todo} yapılacak işini ekledi",
    "You created todo {todo} in list {calendar}" : "{calendar} takvimi listesine {todo} yapılacak işini eklediniz",
    "{actor} deleted todo {todo} from list {calendar}" : "{actor}, {calendar} takvimi listesinden {todo} yapılacak işini sildi",
    "You deleted todo {todo} from list {calendar}" : "{calendar} takvimi listesinden {todo} yapılacak işini sildiniz",
    "{actor} updated todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini güncelledi",
    "You updated todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini güncellediniz",
    "{actor} solved todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini tamamladı",
    "You solved todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini tamamladınız",
    "{actor} reopened todo {todo} in list {calendar}" : "{actor}, {calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattı",
    "You reopened todo {todo} in list {calendar}" : "{calendar} takvimi listesindeki {todo} yapılacak işini yeniden başlattınız",
    "Calendar, contacts and tasks" : "Takvim, kişiler ve görevler",
    "A <strong>calendar</strong> was modified" : "Bir <strong>takvim</strong> düzenlendi",
    "A calendar <strong>event</strong> was modified" : "Bir takvim <strong>etkinliği</strong> düzenlendi",
    "A calendar <strong>todo</strong> was modified" : "Bir takvim <strong>yapılacak işi</strong> düzenlendi",
    "Contact birthdays" : "Kişi doğum günleri",
    "Death of %s" : "%s ölümü",
    "Calendar:" : "Takvim:",
    "Date:" : "Tarih:",
    "Where:" : "Yer:",
    "Description:" : "Açıklama:",
    "Untitled event" : "Adsız etkinlik",
    "_%n year_::_%n years_" : ["%n yıl","%n yıl"],
    "_%n month_::_%n months_" : ["%n ay","%n ay"],
    "_%n day_::_%n days_" : ["%n gün","%n gün"],
    "_%n hour_::_%n hours_" : ["%n saat","%n saat"],
    "_%n minute_::_%n minutes_" : ["%n dakika","%n dakika"],
    "%s (in %s)" : "%s (%s içinde)",
    "%s (%s ago)" : "%s (%s önce)",
    "Calendar: %s" : "Takvim: %s",
    "Date: %s" : "Tarih: %s",
    "Description: %s" : "Açıklama: %s",
    "Where: %s" : "Şurada: %s",
    "%1$s via %2$s" : "%1$s, %2$s aracılığıyla",
    "Cancelled: %1$s" : "İptal edildi: %1$s",
    "Invitation canceled" : "Çağrı iptal edildi",
    "Re: %1$s" : "Ynt: %1$s",
    "Invitation updated" : "Çağrı güncellendi",
    "Invitation: %1$s" : "Çağrı: %1$s",
    "Invitation" : "Çağrı",
    "Title:" : "Başlık:",
    "Time:" : "Zaman:",
    "Location:" : "Konum:",
    "Link:" : "Bağlantı:",
    "Organizer:" : "Düzenleyen:",
    "Attendees:" : "Katılımcılar:",
    "Accept" : "Kabul et",
    "Decline" : "Reddet",
    "More options …" : "Diğer seçenekler …",
    "More options at %s" : "%s üzerindeki diğer seçenekler",
    "Contacts" : "Kişiler",
    "{actor} created address book {addressbook}" : "{actor}, {addressbook} adres defterini ekledi",
    "You created address book {addressbook}" : "{addressbook} adres defterini eklediniz",
    "{actor} deleted address book {addressbook}" : "{actor}, {addressbook} adres defterini sildi",
    "You deleted address book {addressbook}" : "{addressbook} adres defterini sildiniz",
    "{actor} updated address book {addressbook}" : "{actor}, {addressbook} adres defterini güncelledi",
    "You updated address book {addressbook}" : "{addressbook} adres defterini güncellediniz",
    "{actor} shared address book {addressbook} with you" : "{actor}, {addressbook} adres defterini sizinle paylaştı",
    "You shared address book {addressbook} with {user}" : "{addressbook} adres defterini {user} kullanıcısı ile paylaştınız",
    "{actor} shared address book {addressbook} with {user}" : "{actor}, {addressbook} adres defterini {user} kullanıcısı ile paylaştı",
    "{actor} unshared address book {addressbook} from you" : "{actor}, {addressbook} adres defterinin sizinle paylaşımını kaldırdı",
    "You unshared address book {addressbook} from {user}" : "{addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from {user}" : "{actor}, {addressbook} adres defterinin {user} kullanıcısı ile paylaşımını kaldırdı",
    "{actor} unshared address book {addressbook} from themselves" : "{actor}, {addressbook} adres defterinin kendileri ile paylaşımını kaldırdı",
    "You shared address book {addressbook} with group {group}" : "{addressbook} adres defterini {group} grubu ile paylaştınız",
    "{actor} shared address book {addressbook} with group {group}" : "{actor}, {addressbook} adres defterini {group} grubu ile paylaştı",
    "You unshared address book {addressbook} from group {group}" : "{addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdınız",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor}, {addressbook} adres defterinin {group} grubu ile paylaşımını kaldırdı",
    "{actor} created contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterine {card} kişi kartını ekledi",
    "You created contact {card} in address book {addressbook}" : "{addressbook} adres defterine {card} kişi kartını eklediniz",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor}, {addressbook} adres defterinden {card} kişi kartını sildi",
    "You deleted contact {card} from address book {addressbook}" : "{addressbook} adres defterinden {card} kişi kartını sildiniz",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor}, {addressbook} adres defterindeki {card} kişi kartını güncelledi",
    "You updated contact {card} in address book {addressbook}" : "{addressbook} adres defterindeki {card} kişi kartını güncellediniz",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Bir <strong>kişi</strong> ya da <strong>adres defteri</strong> değiştirildi",
    "System is in maintenance mode." : "Sistem bakım kipinde.",
    "Upgrade needed" : "Yükseltme gerekiyor",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "iOS/macOS üzerinde CalDAV ve CardDAV kullanabilmek için %s HTTPS kullanacak şekilde yapılandırılmalıdır.",
    "Configures a CalDAV account" : "Bir CalDAV hesabı yapılandırır",
    "Configures a CardDAV account" : "Bir CardDAV hesabı yapılandırır",
    "Events" : "Etkinlikler",
    "Tasks" : "Görevler",
    "Untitled task" : "Adsız görev",
    "Completed on %s" : "%s tarihinde tamamlandı",
    "Due on %s by %s" : "%s tarihine kadar %s tarafından",
    "Due on %s" : "%s tarihine kadar",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV bağlantı noktası",
    "Availability" : "Kullanılabilirlik",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Çalışma saatlerinizi ayarlarsanız, diğer kullanıcılar bir toplantı ayarladıklarında ofis dışında olduğunuzu görürler.",
    "Time zone:" : "Saat dilimi:",
    "to" : "ile",
    "Delete slot" : "Aralığı sil",
    "No working hours set" : "Çalışma saatleri ayarlanmamış",
    "Add slot" : "Aralık ekle",
    "Save" : "Kaydet",
    "Monday" : "Pazartesi",
    "Tuesday" : "Salı",
    "Wednesday" : "Çarşamba",
    "Thursday" : "Perşembe",
    "Friday" : "Cuma",
    "Saturday" : "Cumartesi",
    "Sunday" : "Pazar",
    "Calendar server" : "Takvim sunucusu",
    "Send invitations to attendees" : "Katılımcılara çağrıları gönder",
    "Automatically generate a birthday calendar" : "Doğum günü takvimi otomatik oluşturulsun",
    "Birthday calendars will be generated by a background job." : "Bu seçenek etkinleştirildiğinde, doğum günü takvimi arka plan görevi olarak oluşturulur.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Etkinleştirildikten hemen sonra görüntülenmez, bir süre sonra görüntülenir.",
    "Send notifications for events" : "Etkinlik bildirimleri gönderilsin",
    "Notifications are sent via background jobs, so these must occur often enough." : "Bildirimler arka plan işlemleri tarafından gönderilir. Bu nedenle sıklık değeri uygun şekilde ayarlanmalıdır.",
    "Enable notifications for events via push" : "Anında etkinlik bildirimleri kullanılsın",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Ayrıca {calendarappstoreopen}Takvim Uygulamasını{linkclose} kurun ya da {calendardocopen}bilgisayarınızı ya da taşınabilir aygıtınızı eşitlemek üzere bağlayın  ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Lütfen {emailopen}e-posta sunucusunu{linkclose} doğru ayarladığınızdan emin olun.",
    "There was an error updating your attendance status." : "Katılım durumunuz güncellenirken bir sorun çıktı.",
    "Please contact the organizer directly." : "Lütfen düzenleyici ile doğrudan görüşün.",
    "Are you accepting the invitation?" : "Çağrıyı kabul ediyor musunuz?",
    "Tentative" : "Kesin değil",
    "Number of guests" : "Konuk sayısı",
    "Comment" : "Yorum",
    "Your attendance was updated successfully." : "Katılımınız güncellendi.",
    "Calendar and tasks" : "Takvim ve görevler"
},
"nplurals=2; plural=(n > 1);");
